
# map/alias props

```jsx
// end use
<Button big />

// maps to
<Button px={4} py={3} fontSize={3} />
```

- shorthand alias for multiple props
- 1:1 props mapping for aliases

```jsx
import styled from 'styled-components'
import {
  space,
  color,
  mapProps
} from 'styled-system'

const el = mapProps(props => ({
  px: props.big ? 4 : null,
  py: props.big ? 3 : null,
  ...props,
}))('button')

const Button = styled(el)`
  ${space}
  ${color}
`

Button.defaultProps = {
}
```

```jsx
// 1:1 api

const alias = map => fn => props => fn(map(props))

const Button = styled.button`
  ${alias(props => ({ px: props.paddingX })(space)}
`
```

```jsx
// or

const alias = dict => fn => props => {
  const next = {}
  for (let key in props) {
    if (dict[key]) {
      next[dict[key]] = props[key]
    } else {
      next[key] = props[key]
    }
  }
  return next
}

const Button = styled.button`
  ${alias({
    paddingLeft: 'pl',
    paddingRight: 'pr',
    paddingTop: 'pt',
    paddingBottom: 'pb',
    paddingX: 'px',
    paddingY: 'py',
  })(space)}
`
```

``jsx

```
